from fastapi.testclient import TestClient

from geomagio.api.ws import app

client = TestClient(app)


def test_get_all_variometers():
    response = client.get("/variometers/")

    assert response.status_code == 200
    body = response.json()
    assert body["type"] == "FeatureCollection"

    variometers = body["features"]
    for v in variometers:
        assert v["type"] == "Feature"
        assert v["id"] != None
        assert v["properties"]["name"] != None
        assert v["properties"]["agency"] != None
        assert v["properties"]["agency_name"] != None
        assert v["properties"]["sensor_orientation"] != None
        assert v["properties"]["sensor_sampling_rate"] == None
        assert v["properties"]["declination_base"] == None
        assert v["geometry"]["type"] == "Point"
        assert len(v["geometry"]["coordinates"]) > 0


def test_get_variometer_by_id():
    response = client.get("/variometers/DWPF")

    assert response.status_code == 200

    body = response.json()
    assert body["type"] == "Feature"
    assert body["id"] == "DWPF"
    assert body["properties"]["name"] == "Disney Wilderness Preserve, Florida, USA"
    assert body["properties"]["agency"] == "USGS"
    assert body["properties"]["agency_name"] == "United States Geological Survey (USGS)"
    assert body["properties"]["sensor_orientation"] == "HDZ"
    assert body["properties"]["sensor_sampling_rate"] == None
    assert body["properties"]["declination_base"] == None
    assert body["geometry"]["type"] == "Point"
    assert body["geometry"]["coordinates"] == [-81.4327, 28.1103, 30]
